Package: elastic
Title: General Purpose Interface to 'Elasticsearch'
Description: Connect to 'Elasticsearch', a 'NoSQL' database built on the 'Java'
    Virtual Machine. Interacts with the 'Elasticsearch' 'HTTP' API
    (<https://www.elastic.co/elasticsearch/>), including functions for
    setting connection details to 'Elasticsearch' instances, loading bulk data,
    searching for documents with both 'HTTP' query variables and 'JSON' based body
    requests. In addition, 'elastic' provides functions for interacting with API's
    for 'indices', documents, nodes, clusters, an interface to the cat API, and
    more.
Version: 1.2.0
License: MIT + file LICENSE
Authors@R: person("Scott", "Chamberlain", role = c("aut", "cre"),
    email = "myrmecocystus@gmail.com",
    comment = c(ORCID="0000-0003-1444-9135"))
URL: https://docs.ropensci.org/elastic/ (website),
        https://github.com/ropensci/elastic
BugReports: https://github.com/ropensci/elastic/issues
Encoding: UTF-8
Language: en-US
Imports: utils, curl (>= 2.2), crul (>= 0.9.0), jsonlite (>= 1.1), R6
Suggests: testthat
RoxygenNote: 7.1.1
X-schema.org-applicationCategory: Databases
X-schema.org-keywords: database, Elasticsearch, HTTP, API, search,
        NoSQL, Java, JSON, documents
X-schema.org-isPartOf: https://ropensci.org
NeedsCompilation: no
Packaged: 2021-03-16 17:50:34 UTC; sckott
Author: Scott Chamberlain [aut, cre] (<https://orcid.org/0000-0003-1444-9135>)
Maintainer: Scott Chamberlain <myrmecocystus@gmail.com>
Repository: CRAN
Date/Publication: 2021-03-16 22:10:05 UTC
Built: R 4.3.3; ; 2025-01-24 15:37:54 UTC; unix
