# Generated by roxygen2: do not edit by hand

S3method(docs_bulk,character)
S3method(docs_bulk,data.frame)
S3method(docs_bulk,default)
S3method(docs_bulk,list)
S3method(docs_bulk_create,data.frame)
S3method(docs_bulk_create,default)
S3method(docs_bulk_delete,data.frame)
S3method(docs_bulk_delete,default)
S3method(docs_bulk_index,data.frame)
S3method(docs_bulk_index,default)
S3method(docs_bulk_prep,data.frame)
S3method(docs_bulk_prep,default)
S3method(docs_bulk_prep,list)
S3method(docs_bulk_update,data.frame)
S3method(docs_bulk_update,default)
S3method(es_parse,bulk_make)
S3method(es_parse,elastic_cluster_health)
S3method(es_parse,elastic_cluster_pending_tasks)
S3method(es_parse,elastic_cluster_settings)
S3method(es_parse,elastic_cluster_state)
S3method(es_parse,elastic_cluster_stats)
S3method(es_parse,elastic_mget)
S3method(es_parse,elastic_nodes_info)
S3method(es_parse,elastic_nodes_stats)
S3method(es_parse,elastic_search)
S3method(es_parse,elastic_stats)
S3method(es_parse,elastic_status)
S3method(es_parse,es_GET)
S3method(es_parse,index_delete)
S3method(scroll,character)
S3method(scroll,default)
S3method(scroll,list)
export(Search)
export(Search_template)
export(Search_template_delete)
export(Search_template_get)
export(Search_template_register)
export(Search_template_render)
export(Search_uri)
export(alias_create)
export(alias_delete)
export(alias_exists)
export(alias_get)
export(alias_rename)
export(aliases_get)
export(cat_)
export(cat_aliases)
export(cat_allocation)
export(cat_count)
export(cat_fielddata)
export(cat_health)
export(cat_indices)
export(cat_master)
export(cat_nodeattrs)
export(cat_nodes)
export(cat_pending_tasks)
export(cat_plugins)
export(cat_recovery)
export(cat_segments)
export(cat_shards)
export(cat_thread_pool)
export(cluster_health)
export(cluster_pending_tasks)
export(cluster_reroute)
export(cluster_settings)
export(cluster_state)
export(cluster_stats)
export(connect)
export(count)
export(docs_bulk)
export(docs_bulk_create)
export(docs_bulk_delete)
export(docs_bulk_index)
export(docs_bulk_prep)
export(docs_bulk_update)
export(docs_create)
export(docs_delete)
export(docs_delete_by_query)
export(docs_get)
export(docs_mget)
export(docs_update)
export(docs_update_by_query)
export(es_parse)
export(explain)
export(field_caps)
export(field_mapping_get)
export(field_stats)
export(index_analyze)
export(index_clear_cache)
export(index_close)
export(index_create)
export(index_delete)
export(index_exists)
export(index_flush)
export(index_forcemerge)
export(index_get)
export(index_open)
export(index_optimize)
export(index_recovery)
export(index_recreate)
export(index_segments)
export(index_settings)
export(index_settings_update)
export(index_shrink)
export(index_stats)
export(index_status)
export(index_template_delete)
export(index_template_exists)
export(index_template_get)
export(index_template_put)
export(index_upgrade)
export(info)
export(mapping_create)
export(mapping_delete)
export(mapping_get)
export(mlt)
export(msearch)
export(mtermvectors)
export(nodes_hot_threads)
export(nodes_info)
export(nodes_shutdown)
export(nodes_stats)
export(percolate_count)
export(percolate_delete)
export(percolate_list)
export(percolate_match)
export(percolate_register)
export(ping)
export(pipeline_attachment)
export(pipeline_create)
export(pipeline_delete)
export(pipeline_get)
export(pipeline_simulate)
export(reindex)
export(scroll)
export(scroll_clear)
export(search_shards)
export(tasks)
export(tasks_cancel)
export(termvectors)
export(tokenizer_set)
export(type_exists)
export(type_remover)
export(validate)
importFrom(R6,R6Class)
importFrom(crul,HttpClient)
importFrom(crul,upload)
importFrom(curl,curl_escape)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(utils,URLdecode)
importFrom(utils,modifyList)
importFrom(utils,read.delim)
importFrom(utils,read.table)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
