---
title: 'Elastic: computing elasticity tensor of crystalline materials'
tags:
  - computational material science
  - ase
  - python
authors:
 - name: Paweł T. Jochym
   orcid: 0000-0003-0427-7333
   affiliation: 1
affiliations:
 - name: Institute of Nuclear Physics, Polish Academy of Sciences, Poland
   index: 1
date: 20 June 2017
bibliography: paper.bib
---

# Summary

Elastic is a set of python routines for calculation of elastic properties of 
crystals (elastic constants, equation of state, sound velocities, etc.). 
It is a third version of the in-house code I have 
written over several years and is implemented as a extension to the
[ASE](https://wiki.fysik.dtu.dk/ase/) system.
The code was a basis for some of my publications and was 
described briefly in these papers. It was also presented 
at [Workshop on ab initio Calculations in Geosciences](http://wolf.ifj.edu.pl/workshop/work2008/)
and used by some of my co-workers. The code is published and developed on 
[github repository](https://github.com/jochym/Elastic) with 
corresponding [elastic web page](https://jochym.github.io/Elastic/) and
on-line documentation placed at [Elastic website](http://wolf.ifj.edu.pl/elastic/) 
and on [ReadTheDocs](http://elastic.rtfd.org/). 

# References
  
